@@ -3,6 +3,7 @@ import hashlib
 
 '''
 采用AES对称加密算法
+pip3 install -i https://pypi.douban.com/simple pycryptodome
 '''
 
 keyStr = "sdf8g4edxuweif80"
@@ -59,6 +60,6 @@ class Encryption(object):
 
 
 if __name__ == '__main__':
-    r = Encryption.encrypt_key("hello asda world")
+    r = Encryption.encrypt_key("kxyxj8XJ1aerman·yibulayingWXDYZX")
     print(r)
     print(Encryption.decrypt_key(r))
