@@ -17,7 +17,7 @@ import time
 
 __client_map = {}
 
-def get_redis_client(label='redis', db=None, config_map=None):
+def get_redis_client(label='redis', db=None, config_map=None, strict=True):
     global __client_map
     label1 = label + str(db)
     if label1 not in __client_map:
@@ -35,36 +35,40 @@ def get_redis_client(label='redis', db=None, config_map=None):
             redis_pass = None
         redis_pool = redis.ConnectionPool(host=redis_host, port=redis_port, password=redis_pass, db=db)
         __client_map[label1] = redis_pool
-    clients = redis.Redis(connection_pool=__client_map[label1])
+    if strict:
+        clients = redis.StrictRedis(connection_pool=__client_map[label1], decode_responses=True)
+    else:
+        clients = redis.StrictRedis(connection_pool=__client_map[label1], decode_responses=False)
     return clients
 
 class RedisOp(object):
-    def __init__(self, label='redis', db=None):
+    def __init__(self, label='redis', db=None, strict=True):
         self.label = label
         self.db = db
+        self.strict = strict
 
     def redis_hkeys(self, name):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         keys = get_con.hkeys(name)
         return keys
 
     def get(self, name):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         keys = get_con.get(name)
         return keys
 
     def set(self, name, value):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         keys = get_con.set(name, value)
         return keys
 
     def redis_hget(self, name, key):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         val = get_con.hget(name, key)
         return val
 
     def redis_hgetall(self, name):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         res_dict = get_con.hgetall(name)
         return res_dict
 
@@ -73,7 +77,7 @@ class RedisOp(object):
         _num = 0
         while _num < 4:
             try:
-                get_con = get_redis_client(label=self.label, db=self.db)
+                get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
                 get_con.hset(name, one_dict[key], json.dumps(one_dict, ensure_ascii=False))
                 return
             except:
@@ -83,7 +87,7 @@ class RedisOp(object):
     # 列表字典
     def other_name_to_redis(self, name, list_dict, key):
         try:
-            get_con = get_redis_client(label=self.label, db=self.db)
+            get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
             write_pip = get_con.pipeline()
             for one_dict in list_dict:
                 plate_value_dict = json.loads(one_dict['plate_value'])
@@ -95,31 +99,31 @@ class RedisOp(object):
             print(e)
 
     def redis_hset(self, name, key, value):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         get_con.hset(name, key, value)
 
     # [(key1,value1),(key2,value2)]
     def redis_hset_tuple(self, name, list_tuple):
-        get_con = get_redis_client(label=self.label, db=self.db)
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         write_pip = get_con.pipeline()
         for one_tuple in list_tuple:
             write_pip.hset(name, one_tuple[0], one_tuple[1])
         write_pip.execute()
 
     def redis_lpush(self, name, list_data):
-        get_redis_client(label=self.label, db=self.db).lpush(name, json.dumps(list_data))
+        get_redis_client(label=self.label, db=self.db, strict=self.strict).lpush(name, json.dumps(list_data))
 
     def redis_expire(self, name, time_pram):
-        get_redis_client(label=self.label, db=self.db).expire(name, time_pram)
+        get_redis_client(label=self.label, db=self.db, strict=self.strict).expire(name, time_pram)
 
     def redis_llen(self, name):
-        return get_redis_client(label=self.label, db=self.db).llen(name)
+        return get_redis_client(label=self.label, db=self.db, strict=self.strict).llen(name)
 
     def redis_lrange(self, name, start, end):
-        return get_redis_client(label=self.label, db=self.db).lrange(name, start, end)
+        return get_redis_client(label=self.label, db=self.db, strict=self.strict).lrange(name, start, end)
 
     def redis_hdel(self, name, *keys):
-        return get_redis_client(label=self.label, db=self.db).hdel(name, *keys)
+        return get_redis_client(label=self.label, db=self.db, strict=self.strict).hdel(name, *keys)
 
 
 if __name__ == '__main__':
